/*
 * (c) 2008 BI, Inc.  All rights reserved.
 * $Source: /usr/local/ndscvsroot/products/cmmo/cmmo-web/src/main/java/com/biperf/cmmo/ui/util/init/WebApplicationContextBootstrapListener.java,v $
 */

package com.biperf.test.jms.init;

import javax.servlet.ServletContext;
import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;

import org.springframework.web.context.ContextLoader;

/**
 * WebApplicationContextBootstrapListener is a bootstrap task for creating and destroying the Spring
 * WebApplicationContext. The creating and destruction of the Spring ApplicationContext will then do
 * most of the creation and destruction of particular classes (based on PostConstruct and PreDestroy
 * annotated objects).
 *
 * @author repko
 * @since Sep 4, 2008
 * @version 1.0
 */
public class WebApplicationContextBootstrapListener implements ServletContextListener
{
  protected ContextLoader contextLoader;

  public void contextInitialized( ServletContextEvent event )
  {
    event.getServletContext().log( "WebApplicationContextBootstrapListener.init" );
    ServletContext servletContext = event.getServletContext();
    contextLoader = createContextLoader();
    contextLoader.initWebApplicationContext( servletContext );
  }

  public void contextDestroyed( ServletContextEvent event )
  {
    event.getServletContext().log( "WebApplicationContextBootstrapListener.destroy" );
    if ( contextLoader != null )
    {
      ServletContext servletContext = event.getServletContext();
      contextLoader.closeWebApplicationContext( servletContext );
    }
  }

  protected ContextLoader createContextLoader()
  {
    return new ContextLoader();
  }

}
